package com.glxp.mipsdl.admin.controller;

import cn.hutool.core.bean.BeanUtil;
import com.glxp.mipsdl.admin.annotation.AuthRuleAnnotation;
import com.glxp.mipsdl.admin.client.http.*;
import com.glxp.mipsdl.admin.entity.thrsys.ThrCorpEntity;
import com.glxp.mipsdl.admin.entity.thrsys.ThrProductsEntity;
import com.glxp.mipsdl.admin.http.request.USignRequest;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.admin.req.dsxyy.*;
import com.glxp.mipsdl.admin.req.phxyy.*;
import com.glxp.mipsdl.admin.req.yxzyy.*;
import com.glxp.mipsdl.common.enums.ResultEnum;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@RestController
public class UdiWmsController {

    @Value("${ONLINE_VESRION_FLAG}")
    private String curFlag;
    @Resource
    YyUCloud31Client pzhzdClient;
    @Autowired
    private TestClient testClient;
    @Resource
    private UdPlatClient udPlatClient;
    @Resource
    private PhxyyClient phxyyClient;
    @Resource
    private ZaxyyClient zaxyyClient;
    @Resource
    private DsxyyClient dsxyyClient;
    @Resource
    private YxzyyClient yxzyyClient;

    //获取erp往来单位信息接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getUnits")
    public BaseResponse getUnits(@RequestBody UdiwmsUnitRequest udiwmsUnitRequest,
                                 BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getUnit(udiwmsUnitRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getUnit(udiwmsUnitRequest);
        } else if (curFlag.equals("PHXYY")) {
            PhUnitRequest phUnitRequest = new PhUnitRequest();
            BeanUtil.copyProperties(udiwmsUnitRequest, phUnitRequest);
            return phxyyClient.getUnit(phUnitRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            PhUnitRequest phUnitRequest = new PhUnitRequest();
            BeanUtil.copyProperties(udiwmsUnitRequest, phUnitRequest);
            return zaxyyClient.getUnit(phUnitRequest);
        } else if (curFlag.equals("DSXYY")) {
            DsUnitRequest dsUnitRequest = new DsUnitRequest();
            BeanUtil.copyProperties(udiwmsUnitRequest, dsUnitRequest);
            return dsxyyClient.getUnit(dsUnitRequest);
        } else if (curFlag.equals("YXXZYY")) {
            YxUnitRequest yxUnitRequest = new YxUnitRequest();
            BeanUtil.copyProperties(udiwmsUnitRequest, yxUnitRequest);
            return yxzyyClient.getUnit(yxUnitRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持往来单位信息查询！");
    }

    //获取ERP产品信息接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getProducts")
    public BaseResponse getProducts(@RequestBody UdiwmsProductRequest udiwmsProductRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getProducts(udiwmsProductRequest);
        } else if (curFlag.equals("YG_UDPLAT_V1.0")) {
            return udPlatClient.getProducts(udiwmsProductRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getProducuts(udiwmsProductRequest);
        } else if (curFlag.equals("PHXYY")) {
            PhProductRequest phProductRequest = new PhProductRequest();
            BeanUtil.copyProperties(udiwmsProductRequest, phProductRequest);
            return phxyyClient.getProducts(phProductRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            PhProductRequest phProductRequest = new PhProductRequest();
            BeanUtil.copyProperties(udiwmsProductRequest, phProductRequest);
            return zaxyyClient.getProducts(phProductRequest);
        } else if (curFlag.equals("DSXYY")) {
            DsProductRequest dsProductRequest = new DsProductRequest();
            BeanUtil.copyProperties(udiwmsProductRequest, dsProductRequest);
            return dsxyyClient.getProducts(dsProductRequest);
        } else if (curFlag.equals("YXXZYY")) {
            YxProductRequest yxProductRequest = new YxProductRequest();
            BeanUtil.copyProperties(udiwmsProductRequest, yxProductRequest);
            return yxzyyClient.getProducts(yxProductRequest);
        }
        return ResultVOUtils.error(500, "当前第三方系统不支持产品信息查询！");
    }

    /**
     * 查询仓库货位码
     *
     * @param udiwmsWarehouseRequest
     * @return
     */
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getWarehouse")
    public BaseResponse getWarehouse(@RequestBody UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getWarehouse(udiwmsWarehouseRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getWarehouse(udiwmsWarehouseRequest);
        } else if (curFlag.equals("PHXYY")) {
            PhWarehouseRequest phWarehouseRequest = new PhWarehouseRequest();
            BeanUtil.copyProperties(udiwmsWarehouseRequest, phWarehouseRequest);
            return phxyyClient.getWarehouse(phWarehouseRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            PhWarehouseRequest phWarehouseRequest = new PhWarehouseRequest();
            BeanUtil.copyProperties(udiwmsWarehouseRequest, phWarehouseRequest);
            return zaxyyClient.getWarehouse(phWarehouseRequest);
        } else if (curFlag.equals("DSXYY")) {
            DsWarehouseRequest dsWarehouseRequest = new DsWarehouseRequest();
            BeanUtil.copyProperties(udiwmsWarehouseRequest, dsWarehouseRequest);
            return dsxyyClient.getWarehouse(dsWarehouseRequest);
        } else if (curFlag.equals("YXXZYY")) {
            YxWarehouseRequest yxWarehouseRequest = new YxWarehouseRequest();
            BeanUtil.copyProperties(udiwmsWarehouseRequest, yxWarehouseRequest);
            return yxzyyClient.getWarehouse(yxWarehouseRequest);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持仓库货位号查询！");
    }

    //获取ERP订单接口
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/getOrders")
    public BaseResponse getOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOrders(udiwmsOrderRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getOrders(udiwmsOrderRequest);
        } else if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOrders(udiwmsOrderRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            return zaxyyClient.getOrders(udiwmsOrderRequest);
        }
        return ResultVOUtils.error(500, "当前第三方系统不支持业务单据查询！");

    }


    //获取ERP单据类型接口
    @PostMapping("/udiwms/erp/getOrderType")
    public BaseResponse getOrderTypes(@RequestBody UdiwmsBusTypeRequest udiwmsBusTypeRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.getBusType(udiwmsBusTypeRequest);
        } else if (curFlag.equals("PHXYY")) {
            PhBusTypeRequest phBusTypeRequest = new PhBusTypeRequest();
            BeanUtil.copyProperties(udiwmsBusTypeRequest, phBusTypeRequest);
            return phxyyClient.getOrderTypes(phBusTypeRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            PhBusTypeRequest phBusTypeRequest = new PhBusTypeRequest();
            BeanUtil.copyProperties(udiwmsBusTypeRequest, phBusTypeRequest);
            return zaxyyClient.getOrderTypes(phBusTypeRequest);
        } else if (curFlag.equals("DSXYY")) {
            DsBusTypeRequest dsBusTypeRequest = new DsBusTypeRequest();
            BeanUtil.copyProperties(udiwmsBusTypeRequest, dsBusTypeRequest);
            return dsxyyClient.getOrderTypes(dsBusTypeRequest);
        } else if (curFlag.equals("YXXZYY")) {
            YxBusTypeRequest yxBusTypeRequest = new YxBusTypeRequest();
            BeanUtil.copyProperties(udiwmsBusTypeRequest, yxBusTypeRequest);
            return yxzyyClient.getOrderTypes(yxBusTypeRequest);
        } else if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOrderTypes(null);
        } else
            return ResultVOUtils.error(500, "当前第三方系统不支持业务单据类型查询！");

    }

    //提交单据
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/submitOrders")
    public BaseResponse submitOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            TestOrderRequest testOrderRequest = new TestOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, testOrderRequest);
            return testClient.addOrders(testOrderRequest);
        } else if (curFlag.equals("PHXYY")) {
            PhOrderRequest phOrderRequest = new PhOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, phOrderRequest);
            return phxyyClient.submitOrders(phOrderRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            ZaxzyyOrderRequest zaxzyyOrderRequest = new ZaxzyyOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, zaxzyyOrderRequest);
            return zaxyyClient.submitOrders(zaxzyyOrderRequest);
        } else if (curFlag.equals("DSXYY")) {
            DsOrderRequest dsOrderRequest = new DsOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, dsOrderRequest);
            return dsxyyClient.submitOrders(dsOrderRequest);
        } else if (curFlag.equals("YXXZYY")) {
            YxOrderRequest yxOrderRequest = new YxOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, yxOrderRequest);
            return yxzyyClient.submitOrders(yxOrderRequest);
        }
        return ResultVOUtils.error(500, "当前第三方系统不支持提交单据！");
    }


    //获取库存产品基本信息（批次号，生产日期，失效日期，仓位号）
    @PostMapping("/udiwms/erp/inv/getEnvProduct")
    public BaseResponse getEnvProduct(@RequestBody UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getInvProducts(udiwmsOnhandRequest);
        } else if (curFlag.equals("TEST")) {
            return testClient.getEnvProduct(udiwmsOnhandRequest);
        } else if (curFlag.equals("ZAXZYY")) {
            return zaxyyClient.getInvProducts(udiwmsOnhandRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");
    }

    //提交第三方产品信息
    @PostMapping("/udiwms/erp/post/product")
    public BaseResponse postProduct(@RequestBody ThrProductsEntity thrProductsEntity) {
        if (curFlag.equals("TEST")) {
            return testClient.postThirdProductS(thrProductsEntity);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");
    }


    //提交第三方往来单位信息
    @PostMapping("/udiwms/erp/post/unit")
    public BaseResponse postUnit(@RequestBody ThrCorpEntity thrCorpEntity) {
        if (curFlag.equals("TEST")) {
            return testClient.postThirdUnits(thrCorpEntity);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");
    }


    //提交单据
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/preIn/submitOrders")
    public BaseResponse submitPreInOrders(@RequestBody UdiwmsPreInOrderRequest udiwmsPreInOrderRequest) {
        if (curFlag.equals("ZAXZYY")) {
            return zaxyyClient.submitPreInOrders(udiwmsPreInOrderRequest);
        }
        return ResultVOUtils.error(500, "当前第三方系统不支持提交单据！");
    }


    //新增单据
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/addOrders")
    public BaseResponse addOrders(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            TestOrderRequest testOrderRequest = new TestOrderRequest();
            BeanUtil.copyProperties(udiwmsOrderRequest, testOrderRequest);
            return testClient.addOrders(testOrderRequest);
        }
        return ResultVOUtils.error(500, "未设置系统版本");
    }

    /**
     * 修改订单
     *
     * @param udiwmsOrderRequest
     * @return
     */
    @AuthRuleAnnotation("")
    @PostMapping("/udiwms/erp/editOrder")
    public BaseResponse editOrder(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("TEST")) {
            return testClient.editOrder(udiwmsOrderRequest);
        }
        return ResultVOUtils.success("修改成功");
    }


    //修改ERP订单接口
    @PostMapping("/udiwms/erp/modifyBill")
    public BaseResponse modifyBill(@RequestBody UdiwmsPostBillRequest udiwmsPostBillRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.modifyBill(udiwmsPostBillRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    //签字ERP订单接口
    @PostMapping("/udiwms/erp/signBill")
    public BaseResponse signBill(@RequestBody USignRequest signRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.signBill(signRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    //获取现存量接口
    @GetMapping("/udiwms/erp/getOnhand")
    public BaseResponse getOnHand(@RequestBody UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            return pzhzdClient.getOnHand(udiwmsOnhandRequest);
        } else
            return ResultVOUtils.error(500, "未设置系统版本！");

    }

    /**
     * 提交采购计划
     *
     * @param udiwmsOrderRequest
     * @return
     */
    @PostMapping("/udiwms/erp/order/postOrder")
    public BaseResponse postOrder(@RequestBody UdiwmsOrderRequest udiwmsOrderRequest) {
        if (curFlag.equals("YG_UDPLAT_V1.0")) {
            return udPlatClient.postOrder(udiwmsOrderRequest);
        }
        return ResultVOUtils.error(500, "未设置系统版本");
    }

    @PostMapping("/udiwms/erp/testThirdSys")
    public BaseResponse testThirdSys() {
        if (curFlag.equals("TEST")) {
            return testClient.testConnect();
        } else if (curFlag.equals("PHXYY")) {
            return phxyyClient.testConnect();
        } else if (curFlag.equals("ZAXZYY")) {
            return zaxyyClient.testConnect();
        } else if (curFlag.equals("DSXYY")) {
            return dsxyyClient.testConnect();
        } else if (curFlag.equals("YXXZYY")) {
            return yxzyyClient.testConnect();
        }
        if (curFlag.equals("YONGYOU_U8_V3.1")) {
            UdiwmsUnitRequest udiwmsUnitRequest = new UdiwmsUnitRequest();
            udiwmsUnitRequest.setPage(1);
            udiwmsUnitRequest.setLimit(2);
            BaseResponse baseResponse = pzhzdClient.getUnit(udiwmsUnitRequest);
            if (baseResponse.getCode() == 20000) {
                return ResultVOUtils.success("连接成功！");
            } else
                return baseResponse;
        } else return ResultVOUtils.error(500, "暂不支持联通性测试！");
    }

}
