package com.glxp.mipsdl.admin.util;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ReflectUtil;
import cn.hutool.core.util.StrUtil;
import com.glxp.mipsdl.admin.dao.basic.BasicThirdSysBusApiDao;
import com.glxp.mipsdl.admin.dao.basic.BussinessLocalTypeDao;
import com.glxp.mipsdl.admin.dao.basic.UdiRelevanceDao;
import com.glxp.mipsdl.admin.dao.basic.UnitMaintainDao;
import com.glxp.mipsdl.admin.dao.inventory.InvSubWarehouseDao;
import com.glxp.mipsdl.admin.dao.inventory.InvWarehouseDao;
import com.glxp.mipsdl.admin.dao.thrsys.ThrInvWarehouseDao;
import com.glxp.mipsdl.admin.dao.thrsys.ThrSubInvWarehouseDao;
import com.glxp.mipsdl.admin.entity.basic.BasicThirdSysBusApiEntity;
import com.glxp.mipsdl.admin.entity.basic.BussinessLocalTypeEntity;
import com.glxp.mipsdl.admin.entity.basic.UdiRelevanceEntity;
import com.glxp.mipsdl.admin.entity.basic.UnitMaintainEntity;
import com.glxp.mipsdl.admin.entity.business.StockOrderDetailEntity;
import com.glxp.mipsdl.admin.entity.inout.WarehouseEntity;
import com.glxp.mipsdl.admin.entity.inventory.InvSubWarehouseEntity;
import com.glxp.mipsdl.admin.entity.inventory.InvWarehouseEntity;
import com.glxp.mipsdl.admin.entity.thrsys.ThrCorpEntity;
import com.glxp.mipsdl.admin.entity.thrsys.ThrInvWarehouseEntity;
import com.glxp.mipsdl.admin.entity.thrsys.ThrProductsEntity;
import com.glxp.mipsdl.admin.entity.thrsys.ThrSubInvWarehouseEntity;
import com.glxp.mipsdl.admin.req.UdiwmsOrderDetail;
import com.glxp.mipsdl.admin.req.basic.BussinessLocalTypeFilterRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class SubmitOrderUtils {

    @Resource
    UnitMaintainDao unitMaintainDao;
    @Resource
    private InvWarehouseDao invWarehouseDao;
    @Resource
    private ThrInvWarehouseDao thrInvWarehouseDao;
    @Resource
    private InvSubWarehouseDao invSubWarehouseDao;
    @Resource
    private ThrSubInvWarehouseDao thrSubInvWarehouseDao;
    @Resource
    private UdiRelevanceDao udiRelevanceDao;
    @Resource
    private BasicThirdSysBusApiDao thirdSysBusApiDao;
    @Resource
    private BussinessLocalTypeDao bussinessLocalTypeDao;


    //获取当前对应单据类型
    public BussinessLocalTypeEntity getCurLocType(String billType) {
        BussinessLocalTypeFilterRequest bussinessLocalTypeFilterRequest = new BussinessLocalTypeFilterRequest();
        bussinessLocalTypeFilterRequest.setAction(billType);
        List<BussinessLocalTypeEntity> bussinessLocalTypeEntities = bussinessLocalTypeDao.filterJoin(bussinessLocalTypeFilterRequest);
        BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeEntities.get(0);
        return bussinessLocalTypeEntity;
    }

    //转换第三方往来单位
    public ThrCorpEntity toCorp(String corpId, String thirdId) {
        ThrCorpEntity thrCorpEntity = new ThrCorpEntity();
        UnitMaintainEntity unitMaintainEntity = unitMaintainDao.selectThirdInfoByErpId(corpId);
        try {
            String thirdCorpId = (String) ReflectUtil.getFieldValue(unitMaintainEntity, unitMaintainEntity.getClass().getField(thirdId));
            thrCorpEntity.setUnitId(thirdCorpId); //往来单位编码，需转换为第三方系统的ID
            String thirdName = ThirdUtils.getThirdName(thirdId);
            String thirdCorpName = (String) ReflectUtil.getFieldValue(unitMaintainEntity, unitMaintainEntity.getClass().getField(thirdName));
            thrCorpEntity.setName(thirdCorpName); //往来单位名称，需转换为第三方系统的名称
            return thrCorpEntity;
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return null;
    }

    //转换第三方仓库信息
    public ThrInvWarehouseEntity toInv(String invCode, String thirdId) {
        InvWarehouseEntity invWarehouseEntity = invWarehouseDao.selectOneByCode(invCode);
        String thrInvCode = (String) ReflectUtil.getFieldValue(invWarehouseEntity, thirdId);
        ThrInvWarehouseEntity thrInvWarehouseEntity = thrInvWarehouseDao.selectByCode(thrInvCode, thirdId);
        return thrInvWarehouseEntity;
    }

    //转换第三方分库信息
    public ThrSubInvWarehouseEntity toSubInv(String invCode, String thirdId) {
        InvSubWarehouseEntity invSubWarehouseEntity = invSubWarehouseDao.selectOneByCode(invCode);
        try {
            String thrInvCode = (String) ReflectUtil.getFieldValue(invSubWarehouseEntity, invSubWarehouseEntity.getClass().getField(thirdId));
            ThrSubInvWarehouseEntity thrSubInvWarehouseEntity = thrSubInvWarehouseDao.selectByCode(thrInvCode, thirdId);
            return thrSubInvWarehouseEntity;
        } catch (NoSuchFieldException e) {
            e.printStackTrace();
        }
        return null;
    }

    //转换第三方产品信息
    public ThrProductsEntity toProduct(StockOrderDetailEntity stockOrderDetailEntity, String thirdId) {
        UdiRelevanceEntity udiRelevanceEntity = udiRelevanceDao.selectById(stockOrderDetailEntity.getRelId());
        String thirdProductId = (String) ReflectUtil.getFieldValue(udiRelevanceEntity, thirdId);
        String thirdName = ThirdUtils.getThirdName(thirdId);
        String thirdProductName = (String) ReflectUtil.getFieldValue(udiRelevanceEntity, thirdName);
        ThrProductsEntity thrProductsEntity = new ThrProductsEntity();
        thrProductsEntity.setCode(thirdProductId);
        thrProductsEntity.setName(thirdProductName);
        return thrProductsEntity;
    }

    //获取单据对应条码信息
    public List<UdiwmsOrderDetail.CodeDetaiEntity> getCodeArray(StockOrderDetailEntity stockOrderDetailEntity, List<WarehouseEntity> warehouseEntities) {
        List<WarehouseEntity> warehouseEntityList = filterCodes(stockOrderDetailEntity, warehouseEntities);
        if (CollUtil.isNotEmpty(warehouseEntityList)) {
            List<UdiwmsOrderDetail.CodeDetaiEntity> codeDetaiEntities = new ArrayList<>();
            warehouseEntityList.forEach(warehouseEntity -> {
                UdiwmsOrderDetail.CodeDetaiEntity codeDetaiEntity = new UdiwmsOrderDetail.CodeDetaiEntity();
                BeanUtils.copyProperties(warehouseEntity, codeDetaiEntity);
                codeDetaiEntities.add(codeDetaiEntity);
            });
            return codeDetaiEntities;
        } else return null;
    }

    //转换第三方单据类型
    public String toBusType(String billType) {
        BasicThirdSysBusApiEntity thirdSysBusApiEntity = thirdSysBusApiDao.selectByCode(billType);
        if (thirdSysBusApiEntity != null) {
            return thirdSysBusApiEntity.getThirdBuyCode();
        }
        return null;
    }

    public List<WarehouseEntity> filterCodes(StockOrderDetailEntity stockOrderDetailEntity, List<WarehouseEntity> warehouseEntities) {
        List<WarehouseEntity> results = new ArrayList<>();
        if (CollUtil.isNotEmpty(warehouseEntities)) {
            for (WarehouseEntity warehouseEntity : warehouseEntities) {
                if (StrUtil.trimToEmpty(warehouseEntity.getRelId()).equals(StrUtil.trimToEmpty(stockOrderDetailEntity.getRelId()))
                        && StrUtil.trimToEmpty(warehouseEntity.getBatchNo()).equals(StrUtil.trimToEmpty(stockOrderDetailEntity.getBatchNo()))
                ) {
                    results.add(warehouseEntity);
                }
            }
        }
        return results;
    }

}
